<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Contenido_model extends CI_Model {

	public function __construct()
	{
		parent::__construct();
		$this->load->database();
		$this->load->library('session');
		$this->load->driver('cache', array('adapter' => 'file', 'key_prefix' => 'ata_'));
	}

	public function carga_informacion(){
		$nombre 	= $this->input->post('nombre');
		$codigo 	= $this->input->post('codigo');
		$materia 	= $this->input->post('materia');
		$tema 		= $this->input->post('tema');
		$subtema 	= $this->input->post('subtema');
		$contenido 	= $this->input->post('contenido');

		$texto = array(
			'idcodigo' 	=> $codigo,
			'idmateria' => $materia,
			'idtema' 	=> $tema,
			'idsubtema' => $subtema,
			'titulo' 	=> $nombre,
			'contenido' => $contenido,
			'idabogado' => $this->session->userdata('consultor_idabogado')
			);

		return $this->db->insert('textos', $texto);
	}

	public function carga_batch($leyes)
	{
		return $this->db->insert_batch('textos', $leyes, TRUE);
		// SELECT materias.idmateria, materias.nombre, temas.idtema, temas.nombre, subtemas.idsubtema, subtemas.nombre FROM materias JOIN temas on materias.idmateria = temas.idmateria JOIN subtemas ON temas.idtema = subtemas.idtema WHERE materias.codigo = ''
	}

	public function busqueda(){
		return $this->db->select('textos.*,codigos.*')
		->from('textos')
		->join('codigos','textos.idcodigo=codigos.idcodigo')
		->get()
		->result_array();
	}

	public function listado_informacion($articulo,$legislacion,$offset = 0, $limit = 2){

		$this->db->from('textos');
		$this->db->select('idtexto as id, idcodigo as codigo, idmateria as materia, idtema as tema, idsubtema as subtema, titulo as nombre')
		->where_in('titulo',$articulo)
		->where_in('idcodigo',$legislacion);
		$this->db->limit($limit, $offset);
		$this->db->order_by('idcodigo','asc');
		$this->db->order_by('idmateria','asc');
		$this->db->order_by('idtema','asc');
		$this->db->order_by('idsubtema','asc');
		$this->db->order_by('titulo','asc');
		$query = $this->db->get();
		//die($this->db->get_compiled_select());
		return $query->result_array();
	}

	function modifica_informacion(){
		$nombre 	= $this->input->post('nombre');
		$codigo 	= $this->input->post('codigo');
		$materia 	= $this->input->post('materia');
		$tema 		= $this->input->post('tema');
		$subtema 	= $this->input->post('subtema');
		$contenido 	= $this->input->post('contenido');
		$id			= $this->input->post('id');

		$texto = array(
			'idtexto'	=> $id,
			'idcodigo' 	=> $codigo,
			'idmateria' => $materia,
			'idtema' 	=> $tema,
			'idsubtema' => $subtema,
			'titulo' 	=> $nombre,
			'contenido' => $contenido,
			'idabogado' => $this->session->userdata('consultor_idabogado')
			);
		$query = array('idtexto' => $id,
			'idabogado' => $this->session->userdata('consultor_idabogado'),
			'ultima_modificacion' => date('Y-m-d H:i:s'));
		$this->db->insert('modificaciones_historial',$query);

		return (null!=$this->session->userdata('consultor_idabogado')) ? $this->db->replace('textos', $texto) : false;
	}

	public function buscar_respuestas($materia = '', $tema = '', $subtema = '', $palabras = array(), $operadores = array()){

		$this->db->select('respuesta')->from('consultas');

		if (sizeof($subtema)>0) {
			$this->db->where_in('subtema', $subtema);
			//$this->db->get_where('textos', array('textos.idsubtema'=>$subtema));
		} 

		if (sizeof($tema)>0) {
			//$this->db->get_where('textos', array('textos.idtema'=>$tema));
			$this->db->where_in('tema', $tema);
		}

		if (sizeof($materia)>0) {
			//$this->db->get_where('textos', array('textos.idmateria'=>$materia));
			$this->db->where_in('materia', $materia);
		}

		$query = $this->db->get();
		//die($this->db->last_query());
		return $query->result();

	}

	public function busca_informacion($materia = '', $tema = '', $subtema = '', $palabras = array(), $operadores = array()){

		$respuesta=array();
		
		$signos_booleanos = array('or' => '' ,
			'and' => '+',
			'not' => '-');

		$condiciones = '';

		foreach ($palabras as $idpalabra => $palabra) {
			if($this->is_null_or_empty_string($palabra))
				continue;

			$condiciones .= $signos_booleanos[$operadores[$idpalabra]] . $palabra . ' ';
		}

		$boolean_search = " AND MATCH (respuesta) AGAINST ('".$condiciones."' IN BOOLEAN MODE)";

		// $category_search = '';

		// if (!$this->is_null_or_empty_string($subtema)) {
		// 	$category_search = ' AND  subtema = '.$subtema;
		// } else if (!$this->is_null_or_empty_string($tema)) {
		// 	$category_search = ' AND tema = '.$tema;
		// } else if (!$this->is_null_or_empty_string($materia)) {
		// 	$category_search = ' AND materia = '.$materia;
		// }

		// $category_search = (!$this->is_null_or_empty_string($category_search)) ? $category_search : '';
		
		// $query_text = "SELECT respuesta FROM consultas ".$boolean_search.$category_search;
		
		// $query = $this->db->query($query_text);
		// $respuesta['respuestas']= $this->db->get()->result();

		///////////////////////////

		$this->db->select('idtexto, titulo, textos.contenido, codigos.idjurisdiccion as estado, codigos.idcodigo');
		$this->db->from('textos');
		$this->db->join('codigos', 'codigos.idcodigo = textos.idcodigo', 'right');

		if (sizeof($subtema)>0) {
			$this->db->where_in('idsubtema', $subtema);
			//$this->db->where_in('subtema',$subtema);
			//$this->db->get_where('textos', array('textos.idsubtema'=>$subtema));
		} 

		if (sizeof($tema)>0) {
			//$this->db->get_where('textos', array('textos.idtema'=>$tema));
			$this->db->where_in('idtema', $tema);
			//$this->db->where_in('tema',$tema);
		}

		if (sizeof($materia)>0) {
			//$this->db-	>get_where('textos', array('textos.idmateria'=>$materia));
			$this->db->where_in('idmateria', $materia);
			//$this->db->where_in('materia',$materia);
		}


		$respuesta['textos']=$this->db->get()->result();
		//$this->db->join('consultas','consultas.idabogado = textos.idabogado');

		$this->db->select('respuesta')->from('consultas');

		if (sizeof($subtema)>0) {
			//$this->db->where_in('idsubtema', $subtema);
			$this->db->where_in('subtema',$subtema);
			//$this->db->get_where('textos', array('textos.idsubtema'=>$subtema));
		} 

		if (sizeof($tema)>0) {
			//$this->db->get_where('textos', array('textos.idtema'=>$tema));
			//$this->db->where_in('idtema', $tema);
			$this->db->where_in('tema',$tema);
		}

		if (sizeof($materia)>0) {
			//$this->db-	>get_where('textos', array('textos.idmateria'=>$materia));
			//$this->db->where_in('idmateria', $materia);
			$this->db->where_in('materia',$materia);
		}

		$consulta=$this->db->get_compiled_select().$boolean_search;


		$respuesta['respuestas']= $this->db->query($consulta)->result();
		//die($this->db->last_query());
		return $respuesta;
		//return $query_text;
	}


	public function elimina_informacion(){
		$id = $this->input->post('id');

		if (!$this->is_null_or_empty_string($id)) {
			if ($this->db->delete('textos', array('idtexto' => $id)) === FALSE) {
				return FALSE;
			} else {
				return TRUE;
			}
			return ;	
		} else {
			return FALSE;
		}
	}

	function get_texto_from_db($id = ''){

		$this->db->from('textos');
		$this->db->join('codigos', 'codigos.idcodigo = textos.idcodigo');
		$this->db->select('idtexto as id, textos.idcodigo as codigo, codigos.idjurisdiccion as estado, idmateria as materia, idtema as tema, idsubtema as subtema, titulo as nombre, contenido as contenido');
		$this->db->where('idtexto=', $id);

		return $this->db->get();
	}

	public function leer_categorias($reload = FALSE){
		if(!$this->cache->file->is_supported() or $this->cache->get('categorias') == FALSE or $reload){

			$this->db->select('idjurisdiccion as id, entidadfederativa as nombre');
			$this->db->from('jurisdicciones');
			$estados = $this->db->get()->result_array();

			$this->db->select('idcodigo as id, idjurisdiccion as idparent, nombre');
			$this->db->from('codigos');
			$codigos = $this->db->get()->result_array();

			//$this->db->select('idmateria as id, nombre');
			$this->db->select('idmateria as id, idcodigo as idparent, nombre');
			$this->db->from('materias');
			$materias = $this->db->get()->result_array();

			$this->db->select('idtema as id, idmateria as idparent, nombre');
			$this->db->from('temas');
			$temas = $this->db->get()->result_array();

			$this->db->select('idsubtema as id, idtema as idparent, nombre');
			$this->db->from('subtemas');
			$subtemas = $this->db->get()->result_array();

			$this->db->select('idconsulta as id, respuesta as nombre');
			$this->db->from('consultas');
			$consultas=$this->db->get()->result_array();

			// $this->db->select('idtexto as id, titulo as nombre');
			// $this->db->from('textos');
			// $textos=$this->db->get()->result_array();
			//die('<pre>'.print_r($textos,1).'</pre>');

			$categorias = array(
				'estados'	=> $estados,
				'codigos' 	=> $codigos,
				'materias' 	=> $materias,
				'temas' 	=> $temas,
				'subtemas' 	=> $subtemas,
				'consultas' => $consultas
				);
			

			if($this->cache->file->is_supported())
				$this->cache->save('categorias', $categorias, 86400);

			return $categorias;

		} else {
			return $this->cache->get('categorias');
		}
	}

	public function comboText(){
		$query=$this->db->select('idtexto,titulo')->from('textos')->get();
		//die($this->db->get_compiled_select());
		return $query->result_array();
	}
	public function comboCodigo(){
		// $query=$this->db->select('codigos.idcodigo,codigos.nombre,textos.titulo')->from('codigos')->join('textos','codigos.idcodigo=textos.idcodigo')->where_in('textos.titulo',$id)->get();
		$query=$this->db->select('textos.*,codigos.*')
		            ->from('textos')
		            ->join('codigos','textos.idcodigo=codigos.idcodigo')
		            ->group_by('codigos.nombre')
		            ->get();
		//die($this->db->get_compiled_select());
		return $query->result_array();
	}

	public function codigo_a_ids(&$codigo)
	{
		$materia = $codigo->getMateria();
		$tema = $codigo->getTema();
		$subtemas = $codigo->getSubtemas();

		
		$this->db->select('materias.idmateria, materias.nombre as materia, temas.idtema, temas.nombre as tema, subtemas.idsubtema, subtemas.nombre as subtema, subtemas.codigo as codigo');
		$this->db->from('materias');
		$this->db->join('temas', 'materias.idmateria = temas.idmateria', 'left');
		$this->db->join('subtemas', 'temas.idtema = subtemas.idtema', 'left');
		$this->db->where('materias.codigo', $materia['codigo']);
		$this->db->where('temas.codigo', $tema['codigo']);
		foreach ($subtemas as $subtema) {
			$wherein[] = $subtema['codigo'];
		}
		$this->db->where_in('subtemas.codigo', $wherein);
		//$this->db->where('subtemas.codigo', $subtemas[0]['codigo']);

		//die($this->db->get_compiled_select());

		$results = $this->db->get()->result_array();

		$first_result = $results[0];

		$materia['id'] = $first_result['idmateria'];
		$materia['nombre'] = $first_result['materia'];
		$tema['id'] = $first_result['idtema'];
		$tema['nombre'] = $first_result['tema'];

		$subtemas = array();

		foreach ($results as $result) {
			$subtema['id'] = $result['idsubtema'];
			$subtema['nombre'] = $result['subtema'];
			$subtema['codigo'] = $result['codigo'];
			$subtemas[] = $subtema;
		}

		$codigo->setMateria($materia);
		$codigo->setTema($tema);
		$codigo->setSubtemas($subtemas);
	}

	public function codigo_expediente(){

		$this->session->consecutivo=-1;
		$materias=$this->input->post('materia');
		$temas=$this->input->post('tema');
		$subtemas=$this->input->post('subtema');

		$materia=array_values($materias)[0];
		$tema=array_values($temas)[0];
		//die('<pre>'.print_r($materia,1).'</pre>');
		$this->db->select('materias.idmateria,materias.codigo as codigomat')->from('materias');
		$this->db->select('temas.idtema,temas.codigo as codigotem')->from('temas');
		$this->db->select('subtemas.idsubtema,subtemas.codigo as codigosub')->from('subtemas');
		
		$this->db->where_in('materias.idmateria',$materia);
		$this->db->where_in('temas.idtema',$tema);
		$this->db->where_in('subtemas.idsubtema',$subtemas);

		$results = $this->db->get()->result_array();
		
	    
	    $id=10001;
	    $num_consecutivo=$this->db->select('num_consecutivo')->where('idcliente',$id)->from('clientes')->get()->result();
        //die($this->db->get_compiled_select());
	    //die('<pre>'.print_r($num_consecutivo,1).'</pre>');
	    $this->session->consecutivo=$num_consecutivo[0]->num_consecutivo + 1;

	   $codigo_subtema='';
		foreach ($results as $value) {
			$codigo_materia=$value['codigomat'];
			$codigo_tema=$value['codigotem'];
			$codigo_subtema.=$value['codigosub'].'-';
			
			
		}

		$codigo=$this->session->consecutivo."/".date('y')."/".$codigo_materia."/".$codigo_tema."-".trim($codigo_subtema, "-");

		return $codigo;
		
	}

	function get_categorias_array(){
		if(!$this->cache->file->is_supported() or $this->cache->get('categorias_array') == FALSE){
			$big_array = array();
			foreach ($this->leer_categorias(TRUE) as $cat_name => $categoria) {
				$array = array();
				foreach ($categoria as $item) {
					$array[$item['id']] = $this->mb_ucfirst($item['nombre']);
				}

				$big_array[$cat_name] = $array;
			}

			return $big_array;
		} else {
			return $this->cache->get('categorias_array');
		}
	}

	function mb_ucfirst($str, $to_lower = false, $charset = 'utf-8')
		{
			$first = mb_strtoupper(mb_substr($str, 0, 1, $charset), $charset);
			$end = mb_substr($str, 1, mb_strlen($str, $charset), $charset);
			// Convert them all to lowercase (if specified)
			if ( $to_lower ) {
				$end = mb_strtolower($end, $charset);
			}
			return $first . $end;
		}

	function is_null_or_empty_string($question){
		
    	return (!isset($question) || trim($question)==='' || trim($question)==='empty');
    	

	}
}

/* End of file contenido_model.php */
/* Location: ./application/models/contenido_model.php */